@@ -26,7 +26,7 @@
 
 void (*diag)(char *, ...);
 
-static const char *ident = "@(#) sacc(omys): " VERSION;
+const char ident[] = "@(#) sacc(omys): " VERSION;
 
 static char intbuf[256]; /* 256B ought to be enough for any URI */
 static char *mainurl;
@@ -576,7 +576,7 @@ static int
 download(Item *item, int dest)
 {
 	char buf[BUFSIZ];
-	struct cnx c;
+	struct cnx c = { 0 };
 	ssize_t r, w;
 
 	if (item->tag == NULL) {
@@ -590,7 +590,6 @@ download(Item *item, int dest)
 			errno = 0;
 			return 0;
 		}
-		c.tls = NULL;
 	}
 
 	w = 0;
@@ -1079,6 +1078,9 @@ setup(void)
 	sigaction(SIGHUP, &sa, NULL);
 	sigaction(SIGTERM, &sa, NULL);
 
+	sa.sa_handler = SIG_IGN;
+	sigaction(SIGCHLD, &sa, NULL);
+
 	if (!mkdtemp(tmpdir))
 		die("mkdir: %s: %s", tmpdir, strerror(errno));
 	if (interactive = isatty(1)) {
